==> vospace-transfer-service-v0.1.1.zip: vospace-transfer-service-v0.1.1/transfer_service/storage_amqp_server.py <==
import os

from amqp_server import AMQPServer
from config import Config
from db_connector import DbConnector


class StorageAMQPServer(AMQPServer):

    def __init__(self, host, port, queue):
        self.type = "storage"
        config = Config("vos_ts.conf")
        self.params = config.loadSection("file_catalog")
        self.dbConn = DbConnector(self.params["user"],
                                  self.params["password"],
                                  self.params["host"],
                                  self.params.getint("port"),
                                  self.params["db"])
        self.storageType = None
        self.storageBasePath = None
        self.storageHostname = None
        self.storageId = None
        self.storageAck = False
        super(StorageAMQPServer, self).__init__(host, port, queue)

    def execute_callback(self, requestBody):
        # 'requestType' attribute is mandatory
        if "requestType" not in requestBody:
            response = { "responseType": "ERROR",
                         "errorCode": 1, 
                         "errorMsg": "Malformed request, missing parameters." }

        elif requestBody["requestType"] == "STORAGE_ADD":
            self.storageType = requestBody["storageType"]
            self.storageBasePath = requestBody["basePath"]
            self.storageBaseUrl = requestBody["baseUrl"]
            self.storageHostname = requestBody["hostname"]

            if self.storageType != "portal":
                if not os.path.exists(self.storageBasePath):
                    response = { "responseType": "ERROR",
                                 "errorCode": 2,
                                 "errorMsg": "Base path doesn't exist."}
                    return response

            self.dbConn.connect()
            result = self.dbConn.insertStorage(self.storageType,
                                               self.storageBasePath,
                                               self.storageBaseUrl,
                                               self.storageHostname)
            self.dbConn.disconnect()

            if result:
                response = { "responseType": "STORAGE_ADD_DONE" }
            else:
                response = { "responseType": "ERROR",
                             "errorCode": 3,
                             "errorMsg": "Storage point already exists." }

        elif requestBody["requestType"] == "STORAGE_DEL_REQ":
            self.dbConn.connect()
            result = self.dbConn.getStorageList()
            self.dbConn.disconnect()

            response = { "responseType": "STORAGE_DEL_ACK",
                         "storageList": result }

            self.storageAck = True

        elif requestBody["requestType"] == "STORAGE_DEL_CON":
            self.storageId = requestBody["storageId"]
            if self.storageAck:
                self.storageAck = False
                self.dbConn.connect()
                result = self.dbConn.deleteStorage(self.storageId)
                self.dbConn.disconnect()

                if result:
                    response = { "responseType": "STORAGE_DEL_DONE" }
                else:
                    response = { "responseType": "ERROR",
                                 "errorCode": 4,
                                 "errorMsg": "This storage location contains some VOSpace nodes. Please, move those nodes to another location." }
            else:
                response = { "responseType": "ERROR",
                             "errorCode": 5,
                             "errorMsg": "Store request not acknowledged." }

        elif requestBody["requestType"] == "STORAGE_LST":
            self.dbConn.connect()
            result = self.dbConn.getStorageList()
            self.dbConn.disconnect()

            response = { "responseType": "STORAGE_LST_DONE",
                         "storageList": result }

        else:
            response = { "responseType": "ERROR",
                         "errorCode": 6,
                         "errorMsg": "Unkown request type." }

        return response

    def run(self):
        print(f"Starting AMQP server of type {self.type}...")
        super(StorageAMQPServer, self).run()

==> vospace-transfer-service-v0.1.2.zip: vospace-transfer-service-v0.1.2/transfer_service/storage_amqp_server.py <==
#!/usr/bin/env python

import os

from amqp_server import AMQPServer
from config import Config
from db_connector import DbConnector


class StorageAMQPServer(AMQPServer):

    def __init__(self, host, port, queue):
        self.type = "storage"
        config = Config("/etc/vos_ts/vos_ts.conf")
        self.params = config.loadSection("file_catalog")
        self.dbConn = DbConnector(self.params["user"],
                                  self.params["password"],
                                  self.params["host"],
                                  self.params.getint("port"),
                                  self.params["db"],
                                  8,
                                  16)
        super(StorageAMQPServer, self).__init__(host, port, queue)

    def execute_callback(self, requestBody):
        # 'requestType' attribute is mandatory
        if "requestType" not in requestBody:
            response = { "responseType": "ERROR",
                         "errorCode": 1, 
                         "errorMsg": "Malformed request, missing parameters." }

        elif requestBody["requestType"] == "STORAGE_ADD":
            storageType = requestBody["storageType"]
            storageBasePath = requestBody["basePath"]
            storageBaseUrl = requestBody["baseUrl"]
            storageHostname = requestBody["hostname"]

            if storageType != "portal":
                if not os.path.exists(storageBasePath):
                    response = { "responseType": "ERROR",
                                 "errorCode": 2,
                                 "errorMsg": "Base path doesn't exist."}
                    return response

            result = self.dbConn.insertStorage(storageType,
                                               storageBasePath,
                                               storageBaseUrl,
                                               storageHostname)

            if result:
                response = { "responseType": "STORAGE_ADD_DONE" }
            else:
                response = { "responseType": "ERROR",
                             "errorCode": 3,
                             "errorMsg": "Storage point already exists." }

        elif requestBody["requestType"] == "STORAGE_DEL_REQ":
            result = self.dbConn.getStorageList()

            response = { "responseType": "STORAGE_DEL_ACK",
                         "storageList": result }

        elif requestBody["requestType"] == "STORAGE_DEL_CON":
            storageId = requestBody["storageId"]
            result = self.dbConn.deleteStorage(storageId)

            if result:
                response = { "responseType": "STORAGE_DEL_DONE" }
            else:
                response = { "responseType": "ERROR",
                             "errorCode": 4,
                             "errorMsg": "This storage location contains some VOSpace nodes. Please, move those nodes to another location." }

        elif requestBody["requestType"] == "STORAGE_LST":
            result = self.dbConn.getStorageList()

            response = { "responseType": "STORAGE_LST_DONE",
                         "storageList": result }

        else:
            response = { "responseType": "ERROR",
                         "errorCode": 5,
                         "errorMsg": "Unkown request type." }

        return response

    def run(self):
        print(f"Starting AMQP server of type {self.type}...")
        super(StorageAMQPServer, self).run()
